@@ -16,7 +16,7 @@
 ***********************************************************************/
 
 static char const RCSID[] =
-"$Id: common.c,v 1.19 2004/10/21 16:21:10 dfs Exp $";
+"$Id: common.c,v 1.21 2006/01/03 03:20:38 dfs Exp $";
 /* For vsnprintf prototype */
 #define _ISOC99_SOURCE 1
 
@@ -557,11 +557,13 @@ sendPADT(PPPoEConnection *conn, char const *msg)
 
     packet.length = htons(plen);
     sendPacket(conn, conn->discoverySocket, &packet, (int) (plen + HDR_SIZE));
+#ifdef DEBUGGING_ENABLED
     if (conn->debugFile) {
 	dumpPacket(conn->debugFile, &packet, "SENT");
 	fprintf(conn->debugFile, "\n");
 	fflush(conn->debugFile);
     }
+#endif
     syslog(LOG_INFO,"Sent PADT");
 }
 
@@ -590,6 +592,42 @@ sendPADTf(PPPoEConnection *conn, char const *fmt, ...)
     sendPADT(conn, msg);
 }
 
+/**********************************************************************
+*%FUNCTION: pktLogErrs
+*%ARGUMENTS:
+* pkt -- packet type (a string)
+* type -- tag type
+* len -- tag length
+* data -- tag data
+* extra -- extra user data
+*%RETURNS:
+* Nothing
+*%DESCRIPTION:
+* Logs error tags
+***********************************************************************/
+void
+pktLogErrs(char const *pkt,
+	   UINT16_t type, UINT16_t len, unsigned char *data,
+	   void *extra)
+{
+    char const *str;
+    char const *fmt = "%s: %s: %.*s";
+    switch(type) {
+    case TAG_SERVICE_NAME_ERROR:
+	str = "Service-Name-Error";
+	break;
+    case TAG_AC_SYSTEM_ERROR:
+	str = "System-Error";
+	break;
+    default:
+	str = "Generic-Error";
+    }
+
+    syslog(LOG_ERR, fmt, pkt, str, (int) len, data);
+    fprintf(stderr, fmt, pkt, str, (int) len, data);
+    fprintf(stderr, "\n");
+}
+
 /**********************************************************************
 *%FUNCTION: parseLogErrs
 *%ARGUMENTS:
@@ -606,18 +644,5 @@ void
 parseLogErrs(UINT16_t type, UINT16_t len, unsigned char *data,
 	     void *extra)
 {
-    switch(type) {
-    case TAG_SERVICE_NAME_ERROR:
-	syslog(LOG_ERR, "PADT: Service-Name-Error: %.*s", (int) len, data);
-	fprintf(stderr, "PADT: Service-Name-Error: %.*s\n", (int) len, data);
-	break;
-    case TAG_AC_SYSTEM_ERROR:
-	syslog(LOG_ERR, "PADT: System-Error: %.*s", (int) len, data);
-	fprintf(stderr, "PADT: System-Error: %.*s\n", (int) len, data);
-	break;
-    case TAG_GENERIC_ERROR:
-	syslog(LOG_ERR, "PADT: Generic-Error: %.*s", (int) len, data);
-	fprintf(stderr, "PADT: Generic-Error: %.*s\n", (int) len, data);
-	break;
-    }
+    pktLogErrs("PADT", type, len, data, extra);
 }
